==> qtjambi-sql-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiSql/QSqlDriver_shell.h <==
#ifndef QSQLDRIVER_SHELL_H
#define QSQLDRIVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSql/qsqldriver.h>
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlError>
#include <QSqlIndex>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlfield.h>
#include <QtSql/qsqlindex.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qsqlresult.h>
#include <QtSql/qtsqlglobal.h>
#include <QtJambi/RegistryAPI>


class QSqlDriver_shell : public QSqlDriver, public QtJambiShellInterface
{
public:
    QSqlDriver_shell(QObject* parent0 = nullptr);
    ~QSqlDriver_shell() override;

    bool beginTransaction() override;
    bool cancelQuery() override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    bool commitTransaction() override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSqlResult* createResult() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QString escapeIdentifier(const QString& identifier0, QSqlDriver::IdentifierType type1) const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString formatValue(const QSqlField& field0, bool trimStrings1) const override;
    QVariant handle() const override;
    bool hasFeature(QSqlDriver::DriverFeature f0) const override;
    bool isIdentifierEscaped(const QString& identifier0, QSqlDriver::IdentifierType type1) const override;
    bool isOpen() const override;
    int maximumIdentifierLength(QSqlDriver::IdentifierType type0) const override;
    bool open(const QString& db0, const QString& user1, const QString& password2, const QString& host3, int port4, const QString& connOpts5) override;
    QSqlIndex primaryIndex(const QString& tableName0) const override;
    QSqlRecord record(const QString& tableName0) const override;
    bool rollbackTransaction() override;
    void setLastError(const QSqlError& e0) override;
    void setOpen(bool o0) override;
    void setOpenError(bool e0) override;
    QString sqlStatement(QSqlDriver::StatementType type0, const QString& tableName1, const QSqlRecord& rec2, bool preparedStatement3) const override;
    QString stripDelimiters(const QString& identifier0, QSqlDriver::IdentifierType type1) const override;
    bool subscribeToNotification(const QString& name0) override;
    QStringList subscribedToNotifications() const override;
    QStringList tables(QSql::TableType tableType0) const override;
    void timerEvent(QTimerEvent* event0) override;
    bool unsubscribeFromNotification(const QString& name0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlDriver_access : public QSqlDriver
{
    jboolean __qt_beginTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_cancelQuery(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_commitTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_createResult(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_escapeIdentifier_cref_QString_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring identifier0, jint type1) const;
    jstring __qt_formatValue_cref_QSqlField_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID field0, jboolean trimStrings1) const;
    jobject __qt_handle(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasFeature_QSqlDriver_DriverFeature_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint f0) const;
    jboolean __qt_isIdentifierEscaped_cref_QString_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring identifier0, jint type1) const;
    jboolean __qt_isOpen(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_maximumIdentifierLength_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0) const;
    jboolean __qt_open_cref_QString_cref_QString_cref_QString_cref_QString_int_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring db0, jstring user1, jstring password2, jstring host3, jint port4, jstring connOpts5);
    jobject __qt_primaryIndex_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring tableName0) const;
    jobject __qt_record_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring tableName0) const;
    jboolean __qt_rollbackTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setLastError_cref_QSqlError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_setOpen_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean o0);
    void __qt_setOpenError_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean e0);
    jstring __qt_sqlStatement_QSqlDriver_StatementType_cref_QString_cref_QSqlRecord_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jstring tableName1, QtJambiNativeID rec2, jboolean preparedStatement3) const;
    jstring __qt_stripDelimiters_cref_QString_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring identifier0, jint type1) const;
    jboolean __qt_subscribeToNotification_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jobject __qt_subscribedToNotifications(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_tables_QSql_TableType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint tableType0) const;
    jboolean __qt_unsubscribeFromNotification_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
};

#endif // QSQLDRIVER_SHELL_H

==> qtjambi-sql-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiSql/QSqlDriver_shell.h <==
#ifndef QSQLDRIVER_SHELL_H
#define QSQLDRIVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSql/qsqldriver.h>
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlError>
#include <QSqlIndex>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlfield.h>
#include <QtSql/qsqlindex.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qsqlresult.h>
#include <QtSql/qtsqlglobal.h>
#include <QtJambi/RegistryAPI>


class QSqlDriver_shell : public QSqlDriver, public QtJambiShellInterface
{
public:
    QSqlDriver_shell(QObject* parent0 = nullptr);
    ~QSqlDriver_shell() override;

    bool beginTransaction() override;
    bool cancelQuery() override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    bool commitTransaction() override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSqlResult* createResult() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QString escapeIdentifier(const QString& identifier0, QSqlDriver::IdentifierType type1) const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString formatValue(const QSqlField& field0, bool trimStrings1) const override;
    QVariant handle() const override;
    bool hasFeature(QSqlDriver::DriverFeature f0) const override;
    bool isIdentifierEscaped(const QString& identifier0, QSqlDriver::IdentifierType type1) const override;
    bool isOpen() const override;
    int maximumIdentifierLength(QSqlDriver::IdentifierType type0) const override;
    bool open(const QString& db0, const QString& user1, const QString& password2, const QString& host3, int port4, const QString& connOpts5) override;
    QSqlIndex primaryIndex(const QString& tableName0) const override;
    QSqlRecord record(const QString& tableName0) const override;
    bool rollbackTransaction() override;
    void setLastError(const QSqlError& e0) override;
    void setOpen(bool o0) override;
    void setOpenError(bool e0) override;
    QString sqlStatement(QSqlDriver::StatementType type0, const QString& tableName1, const QSqlRecord& rec2, bool preparedStatement3) const override;
    QString stripDelimiters(const QString& identifier0, QSqlDriver::IdentifierType type1) const override;
    bool subscribeToNotification(const QString& name0) override;
    QStringList subscribedToNotifications() const override;
    QStringList tables(QSql::TableType tableType0) const override;
    void timerEvent(QTimerEvent* event0) override;
    bool unsubscribeFromNotification(const QString& name0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlDriver_access : public QSqlDriver
{
    jboolean __qt_beginTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_cancelQuery(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_commitTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_createResult_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_escapeIdentifier_cref_QString_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring identifier0, jint type1) const;
    jstring __qt_formatValue_cref_QSqlField_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID field0, jboolean trimStrings1) const;
    jobject __qt_handle_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasFeature_QSqlDriver_DriverFeature_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint f0) const;
    jboolean __qt_isIdentifierEscaped_cref_QString_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring identifier0, jint type1) const;
    jboolean __qt_isOpen_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_maximumIdentifierLength_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0) const;
    jboolean __qt_open_cref_QString_cref_QString_cref_QString_cref_QString_int_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring db0, jstring user1, jstring password2, jstring host3, jint port4, jstring connOpts5);
    jobject __qt_primaryIndex_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring tableName0) const;
    jobject __qt_record_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring tableName0) const;
    jboolean __qt_rollbackTransaction(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setLastError_cref_QSqlError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_setOpen_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean o0);
    void __qt_setOpenError_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean e0);
    jstring __qt_sqlStatement_QSqlDriver_StatementType_cref_QString_cref_QSqlRecord_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jstring tableName1, QtJambiNativeID rec2, jboolean preparedStatement3) const;
    jstring __qt_stripDelimiters_cref_QString_QSqlDriver_IdentifierType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring identifier0, jint type1) const;
    jboolean __qt_subscribeToNotification_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    jobject __qt_subscribedToNotifications_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_tables_QSql_TableType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint tableType0) const;
    jboolean __qt_unsubscribeFromNotification_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
};

#endif // QSQLDRIVER_SHELL_H
